@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -568,8 +568,28 @@ babl_fish_path2 (const Babl *source,
     /* second attempt,. at path length + 1*/
     if (babl->fish_path.conversion_list->count == 0 &&
         max_path_length () + 1 <= BABL_HARD_MAX_PATH_LENGTH)
+    {
       get_conversion_path (&pc, (Babl *) source, 0, max_path_length () + 1, tolerance);
 
+      if (babl->fish_path.conversion_list->count)
+      {
+        fprintf (stderr, "babl is using a rather long chain, room exists for optimization here\n");
+        babl_list_each (babl->fish_path.conversion_list, show_item, NULL);
+      }
+    }
+
+    /* third attempt,. at path length + 2 */
+    if (babl->fish_path.conversion_list->count == 0 &&
+        max_path_length () + 2 <= BABL_HARD_MAX_PATH_LENGTH)
+    {
+      get_conversion_path (&pc, (Babl *) source, 0, max_path_length () + 2, tolerance);
+      if (babl->fish_path.conversion_list->count)
+      {
+        fprintf (stderr, "babl is using very long chain, should be optimized\n");
+        babl_list_each (babl->fish_path.conversion_list, show_item, NULL);
+      }
+    }
+
     babl_in_fish_path--;
     babl_free (pc.current_path);
   }
