@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -392,7 +392,10 @@ static const Babl *babl_trc_from_icc (ICC  *state, int offset,
 
 static void icc_allocate_tag (ICC *state, const char *tag, int size)
 {
-    state->no+=((4-state->o)%4);state->o = state->no;state->psize = size;
+    while (state->no % 4 != 0)
+      state->no++;
+
+    state->o = state->no;state->psize = size;
     icc_write (sign, 128 + 4 + 4 * state->headpos++, tag);
     icc_write (u32,  128 + 4 + 4 * state->headpos++, state->o);
     icc_write (u32,  128 + 4 + 4 * state->headpos++, size);
@@ -484,14 +487,14 @@ switch (trc->type)
 
 static void symmetry_test (ICC *state);
 
-const char *babl_space_to_icc (const Babl  *babl,
-                               const char  *description,
-                               const char  *copyright,
-                               BablICCFlags flags,
-                               int         *ret_length)
+char *babl_space_to_icc (const Babl  *babl,
+                         const char  *description,
+                         const char  *copyright,
+                         BablICCFlags flags,
+                         int         *ret_length)
 {
   const BablSpace *space = &babl->space;
-  static char icc[65536];
+  char icc[65536];
   int length=65535;
   ICC *state = icc_state_new (icc, length, 10);
 
@@ -606,7 +609,25 @@ const char *babl_space_to_icc (const Babl  *babl,
     *ret_length = length;
 
   babl_free (state);
-  return icc;
+  {
+    char *ret = malloc (length);
+    memcpy (ret, icc, length);
+    return ret;
+  }
+}
+
+const char *babl_space_get_icc (const Babl *babl, int *length)
+{
+  if (!babl->space.icc_profile)
+  {
+    /* overriding constness of babl */
+    Babl *babl_noconst = (void*) babl;
+    babl_noconst->space.icc_profile = babl_space_to_icc (babl,
+                              "babl profile", NULL, 0,
+                              &babl_noconst->space.icc_length);
+  }
+  *length = babl->space.icc_length;
+  return babl->space.icc_profile;
 }
 
 
@@ -700,7 +721,7 @@ static char *decode_string (ICC *state, const char *tag, const char *lang, const
 }
 
 const Babl *
-babl_icc_make_space (const char   *icc_data,
+babl_space_from_icc (const char   *icc_data,
                      int           icc_length,
                      BablIccIntent intent,
                      const char  **error)
@@ -844,6 +865,9 @@ babl_icc_make_space (const char   *icc_data,
                 trc_red, trc_green, trc_blue);
 
        babl_free (state);
+       ret->space.icc_length = icc_length;
+       ret->space.icc_profile = malloc (icc_length);
+       memcpy (ret->space.icc_profile, icc_data, icc_length);
        return ret;
      }
   }
@@ -890,6 +914,11 @@ babl_icc_make_space (const char   *icc_data,
                      green_x, green_y,
                      blue_x, blue_y,
                      trc_red, trc_green, trc_blue, 1);
+
+       ret->space.icc_length = icc_length;
+       ret->space.icc_profile = malloc (icc_length);
+       memcpy (ret->space.icc_profile, icc_data, icc_length);
+
        return ret;
      }
   }
@@ -899,6 +928,16 @@ babl_icc_make_space (const char   *icc_data,
   return NULL;
 }
 
+/* NOTE: GIMP-2.10.0-4 releases depends on this symbol */
+const Babl *
+babl_icc_make_space (const char   *icc_data,
+                     int           icc_length,
+                     BablIccIntent intent,
+                     const char  **error)
+{
+  return babl_space_from_icc (icc_data, icc_length, intent, error);
+}
+
 static void symmetry_test (ICC *state)
 {
   icc_write (s8, 8,-2);
