@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -180,3 +180,11 @@ babl_exit (void)
 #endif
     }
 }
+
+#undef babl_model_is
+
+int babl_model_is (const Babl *babl, const char *model)
+{
+  return ((babl)==babl_model_with_space(model, babl));
+}
+
