@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -304,7 +304,10 @@ sse_pow_24 (__v4sf x)
 static inline __v4sf
 linear_to_gamma_2_2_sse2 (__v4sf x)
 {
-  __v4sf curve = sse_pow_1_24 (x) * splat4f (1.055f) - splat4f (0.055f);
+  __v4sf curve = sse_pow_1_24 (x) * splat4f (1.055f) -
+                 splat4f (0.055f                     -
+                          3.0f / (float) (1 << 24));
+                          /* ^ offset the result such that 1 maps to 1 */
   __v4sf line = x * splat4f (12.92f);
   __v4sf mask = _mm_cmpgt_ps (x, splat4f (0.003130804954f));
   return _mm_or_ps (_mm_and_ps (mask, curve), _mm_andnot_ps (mask, line));
@@ -429,7 +432,8 @@ conv_yaF_linear_yaF_gamma (const Babl *conversion,const float *src, float *dst,
 
   while (samples--)
     {
-      *dst++ = babl_linear_to_gamma_2_2 (*src++);
+      float y = *src++;
+      *dst++ = linear_to_gamma_2_2_sse2 (splat4f (y))[0];
       *dst++ = *src++;
     }
 }
@@ -463,7 +467,8 @@ conv_yaF_gamma_yaF_linear (const Babl *conversion,const float *src, float *dst,
 
   while (samples--)
     {
-      *dst++ = babl_gamma_2_2_to_linear (*src++);
+      float y = *src++;
+      *dst++ = gamma_2_2_to_linear_sse2 (splat4f (y))[0];
       *dst++ = *src++;
     }
 }
@@ -500,7 +505,8 @@ conv_yF_linear_yF_gamma (const Babl *conversion,const float *src, float *dst, lo
 
   while (samples--)
     {
-      *dst++ = babl_linear_to_gamma_2_2 (*src++);
+      float y = *src++;
+      *dst++ = linear_to_gamma_2_2_sse2 (splat4f (y))[0];
     }
 }
 
@@ -536,7 +542,8 @@ conv_yF_gamma_yF_linear (const Babl *conversion,const float *src, float *dst, lo
 
   while (samples--)
     {
-      *dst++ = babl_gamma_2_2_to_linear (*src++);
+      float y = *src++;
+      *dst++ = gamma_2_2_to_linear_sse2 (splat4f (y))[0];
     }
 }
 
